<?php
/*!
 *  @file
 *
 *  @brief	table definitions for MySql database
 *
 *  @date	August 22, 2015
 */

/*!
 *  List of table definitions.
 *
 * Format:
 * <pre><code>
 * hws_tables ::= "(" \<table_def\> ("," \<table_def\>)* ");"
 *
 * table_def  ::= "'" \<table_name\> "' => (" ("'" \<col_def\> "',")* "),"
 *
 * col_def    ::= SQL definition
 * </code></pre>
 */ 
$HWS_TABLES = array(

 //----------------------------- COMMON TABLES --------------------------------

 'hardware_groups' => array(
	'id             SMALLINT    NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'hwgroup        VARCHAR(32) NOT NULL',
	'code           VARCHAR(3)  NOT NULL'
 ),
 'device_type' => array(
	'id             SMALLINT    NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'hwgroup_id     SMALLINT    NOT NULL',
	'device_type    VARCHAR(32) NOT NULL',
	'code           VARCHAR(3)  NOT NULL'
 ),
 'bus' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'bus            VARCHAR(25) NOT NULL'
 ),
 'feature_jt' => array(
	'seq_number     INT      NOT NULL',
	'feature_tbl_id SMALLINT NOT NULL',
	'feature_id     INT      NOT NULL'
 ),
 'feature_tables' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'name           VARCHAR(25) NOT NULL'
 ),
 'links' => array(
	'id             INT          NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'physical_id    INT          NOT NULL',
	'comment        TEXT         NOT NULL',
	'url            VARCHAR(255) NOT NULL'
 ),
 'locations' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'location       VARCHAR(25) NOT NULL',
	'street         VARCHAR(30)     NULL',
	'zipcode        VARCHAR(8)      NULL',
	'city           VARCHAR(25)     NULL',
	'room           VARCHAR(4)      NULL',
	'rack           VARCHAR(4)      NULL',
	'shelf          VARCHAR(2)      NULL'
 ),
 'manufacture' => array(
	'id             INT 	    NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'manufacture    VARCHAR(32) NOT NULL'
 ),
 'mapping_ac_dc' => array(
	'label          VARCHAR(2) NOT NULL',
	'value          BOOLEAN    NOT NULL DEFAULT FALSE'
 ),
 'mapping_yes_no' => array(
	'label          VARCHAR(8) NOT NULL',
	'value          BOOLEAN    NOT NULL DEFAULT FALSE'
 ),
 'model' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model          VARCHAR(32) NOT NULL'
 ),
 'news' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'date           DATE        NOT NULL',
	'time           TIME        NOT NULL',
	'subject        VARCHAR(40) NOT NULL DEFAULT \'\'',
	'message        TEXT        NOT NULL DEFAULT \'\''
 ),
 'notes' => array(
	'id             INT  NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'physical_id    INT  NOT NULL',
	'last_date      DATE NOT NULL',
	'last_time      TIME NOT NULL',
	'note           TEXT NOT NULL DEFAULT \'\''
 ),
 'physical' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'hwgroup_id     SMALLINT    NOT NULL',
	'device_type_id SMALLINT    NOT NULL',
	'model_spec_id  INT         NOT NULL',
	'status_id      INT         NOT NULL',
	'location_id    INT             NULL',
	'serial_number  VARCHAR(25) NOT NULL',
	'barcode        VARCHAR(50)     NULL'
 ),
 'physical_history' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'date           DATE    NOT NULL',
	'time           TIME    NOT NULL',
	'physical_id    INT         NULL',
	'user_id        INT         NULL',
	'action         VARCHAR(12) NULL'
 ),
 'status' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'status         VARCHAR(16) NOT NULL'
 ),
 'unit_clock_speed' => array(
	'unit           VARCHAR(6)  NOT NULL',
	'factor         INT         NOT NULL'
 ),
 'unit_length' => array(
	'unit           VARCHAR(6)  NOT NULL',
	'factor         FLOAT(7,3)  NOT NULL'
 ),
 'unit_memory_capacity' => array(
	'unit           VARCHAR(6)  NOT NULL',
	'factor         BIGINT      NOT NULL'
 ),
 'unit_transmission_speed' => array(
	'unit           VARCHAR(6)  NOT NULL',
	'factor         INT         NOT NULL'
 ),
 'users' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'username       VARCHAR(12) NOT NULL',
	'password       VARCHAR(16)     NULL',
	'permissions    CHAR(5)     NOT NULL',
	'fullname       VARCHAR(30)     NULL',
	'locked         BOOLEAN     NOT NULL DEFAULT FALSE'
 ),

 //-------------------------- AUDIO / VIDEO TABLES ----------------------------

 'avi_display' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'diagonal       FLOAT(4,1)  NULL',
	'connector_sqn  INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'avi_graphics_adapter' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'memory         FLOAT(8,3)  NULL',
	'connector_sqn  INT         NULL',
	'bus_id         INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'avi_soundcard' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'input_sqn      INT         NULL',
	'output_sqn     INT         NULL',
	'bus_id         INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'avi_connector' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'connector      VARCHAR(15) NOT NULL'
 ),
 'avi_input' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'input          VARCHAR(15) NOT NULL'
 ),
 'avi_output' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'output         VARCHAR(15) NOT NULL'
 ),

 //----------------------- CORE / ARCHITECTURE TABLES -------------------------

 'coa_processor' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'clock          FLOAT(8,3)  NULL',
	'l2cache        FLOAT(8,3)  NULL',
	'package_id     INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'coa_system_mainboard' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'formfactor_id  INT         NULL',
	'socket_id      INT         NULL',
	'module_type_id INT         NULL',
	'core_io_sqn    INT         NULL',
	'bus_sqn        INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'coa_core_io' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'core_io        VARCHAR(25) NOT NULL'
 ),
 'coa_formfactor' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'formfactor     VARCHAR(15) NOT NULL'
 ),
 'coa_package' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'package        VARCHAR(15) NOT NULL'
 ),
 'coa_socket' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'socket         VARCHAR(15) NOT NULL'
 ),

 //------------------------- COMMUNICATIONS TABLES ----------------------------

 'com_modem' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'speed          MEDIUMINT   NULL',
	'ports          SMALLINT    NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'com_nic' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'topology_id    INT         NULL',
	'speed          INT         NULL',
	'port_sqn       INT         NULL',
	'bus_id         INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'com_router' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'speed          INT         NULL',
	'port_sqn       INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'com_switch' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'speed          INT         NULL',
	'port_id        INT         NULL',
	'aux_port_sqn   INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'com_aux_ports' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'aux_port       VARCHAR(15) NOT NULL',
 ),
 'com_ports' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'port           VARCHAR(15) NOT NULL',
 ),
 'com_topology' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'topology       VARCHAR(15) NOT NULL',
 ),

 //------------------------------- HID TABLES ---------------------------------

 'hid_keyboard' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'interface_id   INT         NULL',
	'connector_id   INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'hid_mouse' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'buttons        TINYINT     NULL',
	'connector_id   INT         NULL',
	'scrollwheel    BOOLEAN NOT NULL DEFAULT FALSE',
	'part_number    VARCHAR(25) NULL'
 ),
 'hid_reader' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'code_type_id   INT         NULL',
	'formfactor_id  INT         NULL',
	'connector_id   INT         NULL',
	'code_type_sqn  INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'hid_code_type' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'code_type      VARCHAR(15) NOT NULL'
 ),
 'hid_connector' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'connector      VARCHAR(15) NOT NULL'
 ),
 'hid_formfactor' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'formfactor     VARCHAR(15) NOT NULL'
 ),
 'hid_interface' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'interface      VARCHAR(15) NOT NULL'
 ),

 //----------------------------- IMAGING TABLES -------------------------------

 'img_printer' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'technology_id  INT         NULL',
	'resolution     SMALLINT    NULL',
	'paper_type_sqn INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'img_scanner' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'scan_type_id   INT         NULL',
	'resolution     SMALLINT    NULL',
	'depth          SMALLINT    NULL',
	'paper_type_sqn INT         NULL',
	'interface_sqn  INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'img_interface' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'interface      VARCHAR(15) NOT NULL'
 ),
 'img_paper_type' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'paper_type     VARCHAR(15) NOT NULL'
 ),
 'img_scan_type' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'scan_type      VARCHAR(15) NOT NULL'
 ),
 'img_technology' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'technology     VARCHAR(15) NOT NULL'
 ),

 //------------------------- POWER / CABLING TABLES ---------------------------

 'pwc_ethernet_cable' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'length         FLOAT(8,3)  NULL',
	'type_id        INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'pwc_scsi_cable' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'length         FLOAT(3,1)  NULL',
	'connector_id   INT         NULL',
	'termination_id INT         NULL',
	'int_ext_use_id INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'pwc_psu' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'output         FLOAT(6,1)  NULL',
	'inlet_id       INT         NULL',
	'outlet_id      INT         NULL',
	'source         BOOLEAN NOT NULL DEFAULT FALSE',
	'formfactor_id  INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'pwc_ups' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'output         FLOAT(6,1)  NULL',
	'outlet_id      INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'pwc_ethernet_type' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'type           VARCHAR(15) NOT NULL'
 ),
 'pwc_inlets' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'inlet          VARCHAR(15) NOT NULL'
 ),
 'pwc_outlets' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'outlet         VARCHAR(15) NOT NULL'
 ),
 'pwc_psu_formfactor' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'formfactor     VARCHAR(15) NOT NULL'
 ),
 'pwc_scsi_term' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'termination    VARCHAR(15) NOT NULL'
 ),
 'pwc_usage' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'int_ext_use    VARCHAR(15) NOT NULL'
 ),

 //------------------------ STORAGE / MEMORY TABLES ---------------------------

 'stm_controller' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'interface_sqn  INT         NULL',
	'bus_id         INT         NULL',
	'channels       TINYINT     NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'stm_floppy_disk' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'capacity       FLOAT(8,3)  NULL',
	'formfactor_id  INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'stm_harddisk' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'capacity       FLOAT(9,3)  NULL',
	'rpm            SMALLINT    NULL',
	'interface_sqn  INT         NULL',
	'connector_id   INT         NULL',
	'formfactor_id  INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'stm_memory' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'module_type_id INT         NULL',
	'memory_type_id INT         NULL',
	'size           FLOAT(8,3)  NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'stm_optical' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'capacity       FLOAT(8,3)  NULL',
	'magazine       SMALLINT    NULL',
	'speed          FLOAT(3,1)  NULL',
	'interface_sqn  INT         NULL',
	'formfactor_id  INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'stm_tape' => array(
	'id             INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id       INT     NOT NULL',
	'manufacture_id INT         NULL',
	'capacity       FLOAT(8,3)  NULL',
	'magazine       SMALLINT    NULL',
	'interface_sqn  INT         NULL',
	'formfactor_id  INT         NULL',
	'part_number    VARCHAR(25) NULL'
 ),
 'stm_connector' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'connector      VARCHAR(15) NOT NULL'
 ),
 'stm_formfactor' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'formfactor     VARCHAR(15) NOT NULL'
 ),
 'stm_interface' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'interface      VARCHAR(15) NOT NULL'
 ),
 'stm_memory_type' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'memory_type    VARCHAR(15) NOT NULL'
 ),
 'stm_module_type' => array(
	'id             INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'module_type    VARCHAR(15) NOT NULL'
 ),

 //----------------------------- SYSTEMS TABLES -------------------------------

 'sys_rack' => array(
	'id              INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id        INT     NOT NULL',
	'manufacture_id  INT         NULL',
	'formfactor      FLOAT(3,1)  NULL',
	'height          TINYINT     NULL',
	'mounting_id     INT         NULL',
	'part_number     VARCHAR(25) NULL'
 ),
 'sys_system' => array(
	'id              INT     NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'model_id        INT     NOT NULL',
	'manufacture_id  INT         NULL',
	'architecture_id INT         NULL',
	'nprocessors     SMALLINT    NULL',
	'memory          FLOAT(12,6) NULL',
	'storage         FLOAT(10,3) NULL',
	'formfactor_id   INT         NULL',
	'part_number     VARCHAR(25) NULL'
 ),
 'sys_architecture' => array(
	'id              INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'architecture    VARCHAR(25) NOT NULL'
 ),
 'sys_formfactor' => array(
	'id              INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'formfactor      VARCHAR(15) NOT NULL'
 ),
 'sys_mounting' => array(
	'id              INT         NOT NULL AUTO_INCREMENT PRIMARY KEY',
	'mounting        VARCHAR(15) NOT NULL'
 ) 
); // end HWS_TABLES
?>
