<?php
/*!
 *  @file
 *
 *  @brief	initial data for HWS tables
 *
 *  @date	August 26, 2015
 */

/*!
 *  List of initial table data.
 *
 * Format:
 * <pre><code>
 * init_data  ::= "(" \<table_data\> ("," \<table_data\>)* ");"
 *
 * table_data ::= "'" \<table_name\> "' => (" \<row_data\> ("," \<row_data\>)* "),"
 *
 * row_data   ::= "'" \<col_data\> (";" \<col_data\>)* "'"
 *
 * col_data   ::= \<col_name\> "=" \<value\>
 * </code></pre>
 *
 * @note
 * The definition of \<row_data\> could also be solved by using an associative
 * array. However, the current definition seems to be more compact and give a
 * better overview of the data, but at the expense of additional processing in
 * the code using the data.
 */
$INIT_DATA = array(

 //----------------------------- COMMON TABLES --------------------------------

 'hardware_groups' => array(
   'hwgroup = Audio / Video;       code = AVI',	/* id=1 */
   'hwgroup = Core / Architecture; code = COA',	/* id=2 */
   'hwgroup = Communications;      code = COM',	/* id=3 */
   'hwgroup = Human Input Devices; code = HID',	/* id=4 */
   'hwgroup = Imaging;             code = IMG',	/* id=5 */
   'hwgroup = Power / Cabling;     code = PWC',	/* id=6 */
   'hwgroup = Storage / Memory;    code = STM',	/* id=7 */
   'hwgroup = Systems;             code = SYS'	/* id=8 */
 ),
 'device_type' => array(
   // hwgroup_id depends on definition order, see above
   'hwgroup_id = 1; device_type = Graphics Adapter; code = GFX',
   'hwgroup_id = 1; device_type = Display;          code = DPY',
   'hwgroup_id = 1; device_type = Soundcard;        code = SND',
   'hwgroup_id = 2; device_type = System Mainboard; code = SMB',
   'hwgroup_id = 2; device_type = Processor;        code = CPU',
   'hwgroup_id = 3; device_type = Modem;            code = MOD',
   'hwgroup_id = 3; device_type = NIC;              code = NIC',
   'hwgroup_id = 3; device_type = Router;           code = ROU',
   'hwgroup_id = 3; device_type = Switch;           code = SWI',
   'hwgroup_id = 4; device_type = Keyboard;         code = KBD',
   'hwgroup_id = 4; device_type = Mouse;            code = PTR',
   'hwgroup_id = 4; device_type = Reader;           code = REA',
   'hwgroup_id = 5; device_type = Printer;          code = PRN',
   'hwgroup_id = 5; device_type = Scanner;          code = SCN',
   'hwgroup_id = 6; device_type = Ethernet Cable;   code = CBE',
   'hwgroup_id = 6; device_type = PSU;              code = PSU',
   'hwgroup_id = 6; device_type = SCSI Cable;       code = CBZ',
   'hwgroup_id = 6; device_type = UPS;              code = UPS',
   'hwgroup_id = 7; device_type = Controller;       code = CTL',
   'hwgroup_id = 7; device_type = Floppy Disk;      code = FDI',
   'hwgroup_id = 7; device_type = Harddisk;         code = HDD',
   'hwgroup_id = 7; device_type = Memory;           code = MEM',
   'hwgroup_id = 7; device_type = Optical;          code = OPT',
   'hwgroup_id = 7; device_type = Tape;             code = TAP',
   'hwgroup_id = 8; device_type = Rack;             code = RAC',
   'hwgroup_id = 8; device_type = System;           code = SYS'
 ),
 'bus' => array(
   'bus = AGP',
   'bus = EISA',
   'bus = GSC',
   'bus = ISA',
   'bus = MCA',
   'bus = NuBus',
   'bus = PCI32',
   'bus = PCI64',
   'bus = PCI-X',
   'bus = PCIe',
   'bus = Q-Bus',
   'bus = S-Bus',
   'bus = TurboChannel',
   'bus = VLB'
 ),
 'feature_tables' => array(
   'name = bus',
   'name = avi_connector',
   'name = avi_input',
   'name = avi_output',
   'name = coa_core_io',
   'name = coa_formfactor',
   'name = coa_package',
   'name = coa_socket',
   'name = com_aux_ports',
   'name = com_ports',
   'name = com_topology',
   'name = hid_code_type',
   'name = hid_connector',
   'name = hid_formfactor',
   'name = hid_interface',
   'name = img_interface',
   'name = img_paper_type',
   'name = img_scan_type',
   'name = img_technology',
   'name = pwc_ethernet_type',
   'name = pwc_inlets',
   'name = pwc_outlets',
   'name = pwc_psu_formfactor',
   'name = pwc_scsi_term',
   'name = pwc_usage',
   'name = stm_connector',
   'name = stm_formfactor',
   'name = stm_interface',
   'name = stm_memory_type',
   'name = stm_module_type',
   'name = sys_architecture',
   'name = sys_formfactor',
   'name = sys_mounting'
 ),
 'manufacture' => array(
   'manufacture = Compaq',
   'manufacture = DEC',
   'manufacture = HP',
   'manufacture = IBM',
   'manufacture = SGI',
   'manufacture = Sun'
 ),
 'mapping_yes_no' => array(
   'label = Yes; value = 1',
   'label = No;  value = 0'
 ),
 'status' => array(
   'status = OK',
   'status = Fail',
   'status = Unknown'
 ),
 'unit_clock_speed' => array(
   'unit = Hz;  factor = 1',
   'unit = kHz; factor = 1000',
   'unit = MHz; factor = 1000000',
   'unit = GHz; factor = 1000000000'
 ),
 'unit_length' => array(
   'unit = mm; factor = 0.001',
   'unit = cm; factor = 0.01',
   'unit = dm; factor = 0.1',
   'unit = m;  factor = 1',
   'unit = km; factor = 1000'
 ),
 'unit_memory_capacity' => array(
   'unit = B;  factor = 1',
   'unit = kB; factor = 1024',
   'unit = MB; factor = 1048576',
   'unit = GB; factor = 1073741824',
   'unit = TB; factor = 1099511627776'
 ),
 'unit_transmission_speed' => array(
   'unit = bps;  factor = 1',
   'unit = kbps; factor = 1000',
   'unit = Mbps; factor = 1000000',
   'unit = Gbps; factor = 1000000000'
 ),

 //-------------------------- AUDIO / VIDEO TABLES ----------------------------

 'avi_connector' => array(
   'connector = BNC (3)',
   'connector = BNC (5)',
   'connector = DB13W3',
   'connector = DB15',
   'connector = DVI',
   'connector = HDMI'
 ),
 'avi_input' => array(
   'input = Line-in',
   'input = Microphone',
   'input = S/PDIF'
 ),
 'avi_output' => array(
   'output = Line-out',
   'output = S/PDIF',
   'output = Speaker'
 ),

 //----------------------- CORE / ARCHITECTURE TABLES -------------------------

 'coa_core_io' => array(
   'core_io = Keyboard DIN',
   'core_io = Keyboard PS/2',
   'core_io = Mouse DIN',
   'core_io = Mouse PS/2',
   'core_io = MMJ',
   'core_io = LAN',
   'core_io = Parallel',
   'core_io = RS232',
   'core_io = USB',
   'core_io = IDE',
   'core_io = SATA',
   'core_io = SCSI',
   'core_io = VGA'
 ),
 'coa_formfactor' => array(
   'formfactor = AT',
   'formfactor = baby-AT',
   'formfactor = ATX',
   'formfactor = uATX',
   'formfactor = Custom'
 ),
 'coa_package' => array(
   'package = IPGA',
   'package = PGA',
   'package = SECC'
 ),
 'coa_socket' => array(
   'socket = Slot A',
   'socket = Socket A',
   'socket = Socket 370',
   'socket = Socket 8',
   'socket = Soldered'
 ),

 //------------------------- COMMUNICATIONS TABLES ----------------------------

 'com_aux_ports' => array(
   'aux_port = AUI',
   'aux_port = BNC',
   'aux_port = LC',
   'aux_port = SC',
   'aux_port = UTP'
 ),
 'com_ports' => array(
   'port = BNC',
   'port = LC',
   'port = SC',
   'port = UTP'
 ),
 'com_topology' => array(
   'topology = ATM',
   'topology = Ethernet',
   'topology = Fiberchannel',
   'topology = Tokenring',
   'topology = VG-Any-LAN'
 ),

 //------------------------------- HID TABLES ---------------------------------

 'hid_connector' => array(
   'connector = Mini-DIN',
   'connector = PS/2'
 ),
 'hid_code_type' => array(
   'code_type = Barcode',
   'code_type = RFID'
 ),
 'hid_formfactor' => array(
   'formfactor = Panel',
   'formfactor = Pen',
   'formfactor = Pistol'
 ),
 'hid_interface' => array(
   'interface = AT'
 ),

 //----------------------------- IMAGING TABLES -------------------------------

 'img_interface' => array(
   'interface = Parallel',
   'interface = SCSI-1',
   'interface = Fast SCSI',
   'interface = USB'
 ),
 'img_paper_type' => array(
   'paper_type = A0',
   'paper_type = A1',
   'paper_type = A2',
   'paper_type = A3',
   'paper_type = A4',
   'paper_type = A5',
   'paper_type = Executive',
   'paper_type = Legal',
   'paper_type = Letter'
 ),
 'img_scan_type' => array(
   'scan_type = Film',
   'scan_type = Flatbed',
   'scan_type = Roller'
 ),
 'img_technology' => array(
   'technology = Dot-matrix',
   'technology = Inktjet',
   'technology = Laser',
   'technology = Plotter',
   'technology = Wax'
 ),

 //------------------------- POWER / CABLING TABLES ---------------------------

 'pwc_ethernet_type' => array(
   'type = Thickwire',
   'type = Thinwire',
   'type = UTP Cross',
   'type = UTP Straight'
 ),
 'pwc_inlets' => array(
   'inlet = C14',
   'inlet = C16'
 ),
 'pwc_outlets' => array(
   'outlet = C13',
   'outlet = C19'
 ),
 'pwc_psu_formfactor' => array(
   'formfactor = AT',
   'formfactor = ATX',
   'formfactor = SBB',
   'formfactor = Custom'
 ),
 'pwc_scsi_term' => array(
   'termination = SE Active',
   'termination = SE Passive',
   'termination = HVD',
   'termination = LVD',
   'termination = LVD/SE',
   'termination = FPT',
   'termination = None'
 ),
 'pwc_usage' => array(
   'int_ext_use = External',
   'int_ext_use = Internal'
 ),
 'mapping_ac_dc' => array(
   'label = AC; value = 1',
   'label = DC; value = 0'
 ),

 //------------------------ STORAGE / MEMORY TABLES ---------------------------

 'stm_connector' => array(
   'connector = DIN41612C',
   'connector = HD50',
   'connector = HD68',
   'connector = SCA-2',
   'connector = VHDCI'
 ),
 'stm_formfactor' => array(
   'formfactor = 3.5" HH',
   'formfactor = 3.5" FH',
   'formfactor = 5.25" HH',
   'formfactor = LP'
 ),
 'stm_interface' => array(
   'interface = ATA',
   'interface = SATA',
   'interface = SCSI1',
   'interface = FastSCSI',
   'interface = FWD',
   'interface = UltraSCSI',
   'interface = Ultra2',
   'interface = Ultra160',
   'interface = Ultra320',
   'interface = DSSI'
 ),
 'stm_memory_type' => array(
   'memory_type = EDO',
   'memory_type = FP'
 ),
 'stm_module_type' => array(
   'module_type = DIMM',
   'module_type = SIMM',
   'module_type = RIMM'
 ),

 //----------------------------- SYSTEMS TABLES -------------------------------

 'sys_architecture' => array(
   'architecture = Alpha',
   'architecture = Itanium',
   'architecture = MIPS',
   'architecture = PA-RISC',
   'architecture = PowerPC',
   'architecture = Sparc',
   'architecture = x86'
 ),
 'sys_formfactor' => array(
   'formfactor = Desktop',
   'formfactor = Pedestal',
   'formfactor = Rack',
   'formfactor = Tower'
 ),
 'sys_mounting' => array(
   'mounting = Imperial',
   'mounting = Metric'
 )
); // end INIT_DATA
?>
