#!/usr/local/bin/php
<?php
/*!
 *  @file
 *
 *  @brief	setup HWS administrator account
 *
 *  <p>
 *  <code>
 *  usage: setup_admin.php \<DOCROOT\> [\<NAME\> [\<PASS\>]]
 *  </code>
 *  </p>
 *
 *  @returns
 *  Exit code 0 is returned if admin account has been created; code 1 is
 *  returned in case of a failure.
 *
 *  @date
 */

function usage()
{
	global $argv;

	fprintf(STDOUT, "
usage: %s <DOCROOT> [<USER> [<PASS>]]

Add a user with administrator privileges to the HWS system. The document root
of HWS is given by DOCROOT. The settings within this document root are used
for accessing the database.
The username and password of the administrator user can be passed as arguments
or they can be omitted. In the latter case the script will run interactively.
This way, the administrator password is not recorded in any of the files, but
only in the HWS database. Note that an empty password for the administrator
is also allowed.
", basename($argv[0]));

	exit(1);
}

//----------------------------- start of script -------------------------------

$docroot = '';
$user    = '';
$pass    = '';

if ($argc < 2 || $argc > 4) usage();

if ($argc >= 2) $docroot = $argv[1];
if ($argc >= 3) $user    = trim($argv[2]);
if ($argc == 4) $pass    = $argv[3];

// work from within document root:
if (is_dir($docroot)) {
	chdir($docroot) || exit(1);
} else {
	fprintf(STDOUT, "%s: directory not found\n", $docroot);
	exit(1);
}

require 'init.php';

fprintf(STDOUT, "\nCreate Administrator Account");
fprintf(STDOUT, "\n----------------------------\n");

if (empty($user)) {
	fprintf(STDOUT, "Enter account name (max. %d):\n", USERNAME_MAX);
	$user = fgets(STDIN, USERNAME_MAX);

	fprintf(STDOUT, "Enter password (max. %d):\n", PASSWORD_MAX);
	system('stty -echo');
	$pass = fgets(STDIN, PASSWORD_MAX);
	system('stty echo');
} else {
	fprintf(STDOUT, "creating account for: %s\n", $user);
}
$crypt_pass = encrypt_password($pass);
$uid = $DB->AddUser($user, base64_encode($crypt_pass), 'rwdm', 'Administrator');
$ret = $DB->ModUserInfo($uid, array('locked' => false));

exit($ret == false ? 1 : 0);	// convert to UNIX exit code
?>
