<?php
/*!
 *  @file
 *
 *  @brief	write devices to local file
 *
 *  @date	May 20, 2016
 */

require 'inc/func_dtd.php';
require 'inc/PDD.inc';

has_permissions('w') || fatal(E_NOPERM);

$gid = validate_integer($_POST['gid']);
$tid = validate_integer($_POST['tid']);

$dtd = get_dtd_pathname($tid);
require $dtd;

echo '
	<h4>Exporting devices for '.filter_string($DB->GetDeviceTypeDesc($tid)).'...</h4>
';

/*
 * Determine column names of physical device and the device type
 * (i.e., serial number, part number, model etc).
 */
$all_col_names =
	array_values(			// -> eliminate array keys
		array_map(		// -> collect column names
			function($e)	// -> get one column name
			{
				return $e[1];
			},
			array_merge($PDD['features'], $DTD['features'])
		)
	);

/*
 * Begin creating CSV entries. At first the entries are
 * saved on a list. Later on they are written to file.
 */
$csv_list    = array();
$num_written = 0;
$num_fail    = 0;
$model_list = $DB->ListModels($DTD['table'], $DTD['features']);
foreach ($model_list as $model) {
	/*
	 * Translate value of certain data types for proper representation
	 * in CSV-file (e.g., checkboxes, radio buttons).
	 */
	foreach ($DTD['features'] as $k => $v) {
		// $v[0]: feature table
		// $v[1]: feature column name
		// $v[3]: feature data type
		// $v[4]: type-specific data (e.g., mapping table)
		if ($v[3] == RBTN && !empty($v[4])) {
			$label = $DB->FetchByValue($v[4],
				array('value' => $model["$v[1]"]));
			$model["$v[1]"] = filter_string($label[0]['label']);
		} else if ($v[3] == CBOX) {
			$ids = array();
			$sel = array();
			$ret = $DB->FetchByValue('feature_jt',
				array('seq_number' => $model["$v[1]" . '_sqn']));
			foreach ($ret as $e) array_push($ids, $e['feature_id']);
			if (!empty($ids)) {
				// FetchByMultiValue() fetches all rows if values
				// have been omitted which is not what we want here
				$ret = $DB->FetchByMultiValue($v[0], 'id', $ids);
				foreach ($ret as $e) array_push($sel, $e["$v[1]"]);
			}
			$model["$v[1]"] = filter_string(implode(',', $sel));
			// sequence number can be removed:
			unset($model["$v[1]" . '_sqn']);
		}
	}

	/*
	 * Retrieve all physical devices for this model and add to
	 * CSV-list. Note that these devices are of the same model, so
	 * they share the same features.
	 */
	$dev_list = $DB->ListDevices($gid, $tid, $model['id'], 'serial_number');
	foreach ($dev_list as $dev) {
		// filter necessary columns from results and add to list:
		$all_entries = array_merge($dev, $model);
		$csv_entries = array_intersect_key($all_entries,
				array_flip($all_col_names));
		if (!empty($csv_entries)) {
			$csv_list[] = array_values($csv_entries);
			++$num_written;
		} else {
			++$num_fail;
		}
	}
}
// add column names at top of list:
array_unshift($csv_list, array_keys($csv_entries));

/*
 * Write CSV-entries to file.
 */
$outfile = tempnam(sys_get_temp_dir(), '');
$hnd = fopen($outfile, 'w+');
if ($hnd) {
	foreach ($csv_list as $v) {
		fputcsv($hnd, $v);
	}
	fclose($hnd);
} else {
	fatal(E_FCREATE);
}

echo '
	<form name="model_export" method="post" action="?component=model&action=list&gid='.$gid.'&tid='.$tid.'">
		<table class="std_input">
			<tr>
				<td class="std_input_title">Total Number of Records:</td>
				<td class="std_input_item">'.($num_written+$num_fail).'</td>
			</tr>
			<tr>
				<td class="std_input_title">Records inserted:</td>
				<td class="std_input_item">'.$num_written.'</td>
			</tr>
			<tr>
				<td class="std_input_title">Failed insertions:</td>
				<td class="std_input_item">'.$num_fail.'</td>
			</tr>
			<tr>
				<td class="std_input_buttons" colspan="2"><input type="submit" value="OK"></td>
			</tr>
		</table>
	</form>
';

/*
 * Trigger a file selector box for downloading/saving the CSV-file.
 */
echo '
	<iframe src="download.php?name='.basename($outfile).'&type=text/csv" style="display:none;"></iframe>
';
?>
