<?php
/*!
 *  @file
 *
 *  @brief	show input dialog for editing a device model
 *
 *  @date	2005
 */

require 'inc/func_dtd.php';
require 'inc/PDD.inc';

has_permissions('w') || fatal(E_NOPERM);

$redir_back = $_SERVER['HTTP_REFERER'];

$gid = validate_integer($_GET['gid']);
$tid = validate_integer($_GET['tid']);

$dtd = get_dtd_pathname($tid);
require $dtd;

$msid = trim($_GET['msid']);	// optional parameter
if (!empty($msid)) {
	validate_integer($msid);

	$row = $DB->GetModelFeatures($DTD['table'], $DTD['features'], $msid);
} else {
	$row = array();
}

$dt_desc = $DB->GetDeviceTypeDesc($tid);
if ($dt_desc === false || empty($dt_desc)) {
	$dt_desc = 'Model';	// fall-back text
}

echo '
	<h2>Edit '.filter_string($dt_desc).'</h2>
	<form name="model_form" method="post" action="?component=model&action=save&gid='.$gid.'&tid='.$tid.'" onsubmit="return CheckFormModel(model_form)">
		<table class="std_input">
';

/*
 * Compile FORM of editable features (in order of appearance).
 */
foreach (array_merge($PDD['features'], $DTD['features']) as $k => $s) {
	$table    = $s[0];	// feature table
	$column   = $s[1];	// feature column name
	$title    = $s[2];	// column title
	$type     = $s[3];	// datatype of column
	$data     = $s[4];	// type-dependent data field
	$required = $s[5];	// flag: input required
	$unit     = $s[6];	// default unit
	$mark     = '';		// mark input field with '*' or not

	if (!empty($unit)) $title .= ' ('.$unit.')';

	echo '
			<tr>
				<td class="std_input_title">'.filter_string($title).':</td>
';

	if ($required) $mark = '<sup> *</sup>';

	/*
	 * Format FORM input field for this feature depending on its datatype.
	 * The "name" attribute is named after the feature column with the
	 * datatype postfixed (lowercase).
	 */
	switch ($type) {
	case TEXT:
		// $data: maximum size text field
		$feat_input = fmt_text_input($column, $row[$column], 15, $data);
		break;
	case MENU:
		// $data: maximum size "Other" text field
		$feat_input  = fmt_dropdown_menu($table, $column, $row[$column], true);
		$feat_input .= '&nbsp;';
		$feat_input .= fmt_text_input($column, '', 15, $data);
		break;
	case RBTN:
		// $data: mapping table w/ radio button label/value pairs
		$labels = array();
		if (!empty($data)) {
			// must collapse 2D array of Fetch():
			foreach ($DB->Fetch($data, array('label')) as $e) {
				array_push($labels, current($e));
			}
			// determine pre-selected button, if any:
			$ret = $DB->FetchByValue($data, array('value' => $row[$column]));
			$sel = $ret[0]['label']; // there should only be 1 match
		} else {
			$sel = $row[$column];
		}
		$feat_input = implode('', fmt_rbtn_input($column,$labels,$sel));
		break;
	case CBOX:
		// $data: checkboxes per line
		$ids = array();
		$sel = array();
		// retrieve feature IDs associated with sequence number...
		$ret = $DB->FetchByValue('feature_jt', array('seq_number' => $row[$column . '_sqn']));
		foreach ($ret as $e) {
			array_push($ids, $e['feature_id']);
		}
		// ...retrieve labels associated with feature IDs, if any
		if (!empty($ids)) {
			$ret = $DB->FetchByMultiValue($table, 'id', $ids);
			foreach ($ret as $e) {
				array_push($sel, $e[$column]);
			}
		}
		// ...and format checkboxes
		$cbs = fmt_cbox_input($table, $column, $sel);

		// TODO: "std_input" table keeps filling 100% width except when
		//       setting an absolute max-width for <ul>
		$width = 100 / $data;	// percentage
		$feat_input = '<ul style="list-style-type:none;padding:0;margin:0;max-width:350px">';
		foreach ($cbs as $c) {
			$feat_input .= '<li style="float:left;width:'.$width.'%">'.$c.'</li>';
		}
		$feat_input .= '</ul>';
		break;
	default:
		fatal(E_DATATYPE);
	}
	echo '
				<td class="std_input_item">
					'.$feat_input.$mark.'
				</td>
			</tr>
';
}

echo '
			<tr>
				<td class="std_input_buttons" style="text-align:left">
					<input type="reset" value="Undo">
				</td>
				<td class="std_input_buttons" style="text-align:right">
					<input type="submit" value="Save">
					<input type="button" value="Cancel" onclick="RedirectPage(\''.filter_string($redir_back).'\')">
				</td>
			</tr>
		</table>
		<input type="hidden" name="redirect" value="'.filter_string($_POST['redirect']).'">
	</form>
	<br>
	<font size="2">*) Required field</font>
';
?>
