<?php
/*!
 *  @file
 *
 *  @brief	show overview of available device models
 *
 *  @date	2005
 */

require 'inc/func_dtd.php';

$gid = validate_integer($_GET['gid']);
$tid = validate_integer($_GET['tid']);

$dtd = get_dtd_pathname($tid);
require $dtd;

$parm_list = url_strip_parm($_SERVER['QUERY_STRING'], 'order');
$href_sub = $_SERVER['PHP_SELF'] . '?' . filter_string($parm_list);

echo '
	<h2>'.filter_string($DB->GetDeviceTypeDesc($tid)).'</h2>
	<table class="std_list">
		<tr>
';

// create order parameter for each table in the $DTD structure:
foreach ($DTD['features'] as $k => $s) {
	$title = $s[2];

	if (!empty($s[6])) $title .= ' ('.$s[6].')'; // $s[6]: default unit

	echo '
			<th class="std_list_header">
				<a href="'.$href_sub.'&order='.$s[1].'">'.filter_string($title).'</a>
			</th>
';
}

echo '
			<th class="std_list_header">Qty</th>
';
if (has_permissions('w')) { 	// duplicating models only with write perm.
	echo '
			<th class="std_list_header"><!-- empty --></th>
';
}
echo '
		</tr>
';

// determine sorting order:
$order = trim($_GET['order']);
$new_order = 'model';		// default order
foreach ($DTD['features'] as $k => $s) {
	if (strcasecmp($order, $s[1]) == 0) {
		$new_order = $s[1];
		break;
	}
}
$order = $new_order;

// retrieve model data and add to table:
$ret = $DB->ListModels($DTD['table'], $DTD['features'], $order);
foreach ($ret as $row) {
	echo '
		<tr>
';
	foreach ($DTD['features'] as $k => $s) {
		// $s[0]: feature table
		// $s[1]: feature column name
		// $s[3]: feature data type
		// $s[4]: type-specific data

		if (strcmp($s[1], 'model') == 0) {
			$item  = '<a href="?component=physical&action=list&gid=' . $gid;
			$item .= '&tid=' . $tid . '&msid=' . $row['id'];
			$item .= '">' . filter_string($row['model']) . '</a>';
		} else {
			// determine value for specified column of feat. table:
			switch ($s[3]) {
			case RBTN:
				// substitute mapping label for mapping value;
				// note: type-specific data is mapping table
				$label = $DB->FetchByValue($s[4], array('value' => $row["$s[1]"]));
				$item = filter_string($label[0]['label']);
				break;
			case CBOX:
				$ids = array();
				$sel = array();
				$ret = $DB->FetchByValue('feature_jt', array('seq_number' => $row["$s[1]" . '_sqn']));
				foreach ($ret as $e) array_push($ids, $e['feature_id']);
				if (!empty($ids)) {
					// FetchByMultiValue() fetches all rows if values
					// have been omitted which is not what we want here
					$ret = $DB->FetchByMultiValue($s[0], 'id', $ids);
					foreach ($ret as $e) array_push($sel, $e["$s[1]"]);
				}
				$item = filter_string(implode(', ', $sel));
				break;
			default:
				$item = filter_string($row["$s[1]"]);
			}
		}
		echo '
			<td class="std_list_entry">'.$item.'</td>
';
	}
	echo '
			<td class="std_list_entry">'.filter_string($DB->GetNumberOfPhysicalDevices($gid, $tid, $row['id'])).'</td>
';

	if (has_permissions('w')) {
		echo '
			<td class="std_list_entry">
				<a href="?component=model&action=edit&gid='.$gid.'&tid='.$tid.'&msid='.$row['id'].'">
					<img src="images/duplicate.png" alt="Duplicate Model">
				</a>
			</td>
';
	}
	echo '
		</tr>
';
}

echo '
	</table>
	<br>
';

if (has_permissions('w')) {
	echo '
	<a href="?component=model&action=edit&gid='.$gid.'&tid='.$tid.'">
		<img src="images/bnew_model.png" alt="New Model">
	</a>
	<a href="?component=model&action=import&gid='.$gid.'&tid='.$tid.'">
		<img src="images/bimport_devices.png" alt="Import Devices">
	</a>
	<a href="?component=model&action=export&gid='.$gid.'&tid='.$tid.'">
		<img src="images/bexport_devices.png" alt="Export Devices">
	</a>
';
}
?>
