<?php
/*!
 *  @file
 *
 *  @brief	add or update device model
 *
 *  @date	2005
 */

require 'inc/func_dtd.php';
require 'inc/PDD.inc';

has_permissions('w') || fatal(E_NOPERM);

$gid = validate_integer($_GET['gid']);
$tid = validate_integer($_GET['tid']);

$dtd = get_dtd_pathname($tid);
require $dtd;

// get physical device fields & values from FORM:
$physical_feats = extract_features_form($PDD['features'], $_POST);

/*
 * Check if model and physical device already exists and add if necessary.
 * A physical device (identified by its S/N) must be unique and is an
 * error if it's already present.
 */
$did = $DB->GetPhysicalDeviceId($gid, $tid,
				$physical_feats['serial_number']['value']);
if ($did == 0) {
	$model_feats = extract_features_form($DTD['features'], $_POST);

	/*
	 * Find or store (if necessary) user-input of model features (FORM
	 * input) and save the returned IDs. An array is declared which will
	 * hold the IDs of the key features used for the model. An entry for
	 * a certain manufacture would be stored as follows:
	 *
	 * 'manufacture_id' (column) => '2' (id)
	 *
	 * Features not stored by ID are copied as-is.
	 */
	$msids = resolve_feature_ids($DTD['table'], $model_feats);
	/*
	 * Additional processing of features.
	 */
	foreach ($DTD['features'] as $v) {
		// $v[0]: feature table name
		// $v[1]: feature column name
		// $v[3]: feature data type
		// $v[4]: type-specific data (e.g., mapping table)
		// $v[6]: default unit
		// $v[7]: unit mapping table

		$ftvalue = trim($msids["$v[1]"]);
		if (empty($ftvalue)) continue;	// skip empty feature values

		if ($v[3] == TEXT && !empty($v[7])) {
			// resolve unit
			$num = convert_value($ftvalue, $v[6], $v[7]);
			if ($num === false) {
				fatal(E_CONVERT);
			} else {
				$msids["$v[1]"] = $num;
			}
		} else if ($v[3] == RBTN && !empty($v[4])) {
			// get mapping label from $msids and lookup
			// associated value in mapping table:
			$mapping = array('label' => $ftvalue);
			$value = $DB->FetchByValue($v[4], $mapping);
			$msids["$v[1]"] = $value[0]['value'];
		} else if ($v[3] == CBOX) {
			// these columns will be replaced by "*_sqn" names:
			unset($msids["$v[1]"]);
		}
	}
	/*
	 * Resolve junction table sequence numbers and
	 * merge with model-specific IDs.
	 */
	$jtsn = resolve_jtable_sqn($DTD['table'], $model_feats);
	$msids = array_merge($msids, $jtsn);

	/*
	 * Query database for model. If this results empty then there's no
	 * entry for the model, yet. In this case we'll add the model.
	 */
	$row = $DB->FetchByValue($DTD['table'], $msids);
	if (empty($row)) {
		// save model specific id:
		$msid = $DB->Insert($DTD['table'], $msids);
	} else {
		$msid = $row[0]['id']; // model specific id (entry) existed
	}

	/*
	 * Find or store (if necessary) user-input of physical device
	 * features, just as above.
	 */
	$phids = resolve_feature_ids('physical', $physical_feats);

	$fields = array('hwgroup_id'     => $gid,
			'device_type_id' => $tid,
			'model_spec_id'  => $msid,
			'status_id'      => $phids['status_id'],
			'location_id'    => $phids['location_id'],
			'serial_number'  => $physical_feats['serial_number']['value'],
			'barcode'        => $physical_feats['barcode']['value']);
	$DB->Insert('physical', $fields);
} else {
	fatal(E_SNEXIST);
}

header('Location: http://' . $_SERVER['SERVER_NAME'] . '?component=model&action=list&gid='.$gid.'&tid='.$tid);
exit;
?>
