<?php
/*!
 *  @file
 *
 *  @brief	show input dialog for editting physical device properties
 *
 *  @date	2005
 */

require 'inc/func_dtd.php';
require 'inc/PDD.inc';

has_permissions('w') || fatal(E_NOPERM);

$redir_back = $_SERVER['HTTP_REFERER'];

$did = validate_integer($_GET['did']);

$row  = $DB->GetDeviceState($did);
$gid  = validate_integer($row['hwgroup_id']);
$tid  = validate_integer($row['device_type_id']);
$msid = validate_integer($row['model_spec_id']);

$dtd = get_dtd_pathname($tid);
require $dtd;

$ret = $DB->GetModelFeatures($DTD['table'], $DTD['features'], $msid); // overkill
if ($ret) {
	$model_name = $ret['model'];
}
if (empty($model_name)) fatal(E_NOMODEL);

echo '
	<h2>Edit '.filter_string($model_name).' : '.filter_string($row['serial_number']).'</h2>
	<form name="physical" action="?component=physical&action=save&did='.$did.'" method="post" onsubmit="return CheckFormPhysical(physical)">
		<table class="std_input">
';

/*
 * Compile FORM of editable features (in order of appearance).
 */
foreach ($PDD['features'] as $k => $s) {
	$table    = $s[0];	// feature table
	$column   = $s[1];	// feature column name
	$title    = $s[2];	// column title
	$type     = $s[3];	// datatype of column
	$data     = $s[4];	// type-dependent data field
	$required = $s[5];	// flag: input required
	$mark     = '';		// mark input field with '*' or not

	echo '
			<tr>
				<td class="std_input_title">'.filter_string($title).':</td>
';

	if ($required) $mark = '<sup> *</sup>';

	/*
	 * Format FORM input field for this feature depending on its datatype.
	 * The "name" attribute is named after the feature column with the
	 * datatype postfixed (lowercase).
	 */
	switch ($type) {
	case TEXT: 
		// $data: maximum size text field
		$feat_input = fmt_text_input($column, $row[$column], 15, $data);
		break;
	case MENU:
		// $data: maximum size "Other" text field
		$feat_input  = fmt_dropdown_menu($table, $column, $row[$column], true);
		$feat_input .= '&nbsp;';
		$feat_input .= fmt_text_input($column, '', 15, $data);
		break;
	case RBTN:
		// $data: mapping table w/ radio button label/value pairs
		$labels = array();
		if (!empty($data)) {
			// must collapse 2D array of Fetch():
			foreach($DB->Fetch($data, array('label')) as $e) {
				array_push($labels, current($e));
			}
			// determine pre-selected button, if any:
			if (!empty($row[$column])) {
				$ret = $DB->FetchByValue($data, array('value' => $row[$column]));
				$sel = $ret[0]['label']; // there should only be 1 match
			} else {
				$sel = '';
			}
		} else {
			$sel = $row[$column];
		}
		$feat_input = implode('', fmt_rbtn_input($column,$labels,$sel));
		break;
	default:
		fatal(E_DATATYPE);
	}
	echo '
				<td class="std_input_item">
					'.$feat_input.$mark.'
				</td>
			</tr>
';
}

echo '
			<tr>
				<td class="std_input_buttons" style="text-align:left">
					<input type="reset"  value="Undo">
				</td>
				<td class="std_input_buttons" style="text-align:right">
					<input type="submit" value="Save">
					<input type="button" value="Cancel" onclick="RedirectPage(\''.filter_string($redir_back).'\')">
				</td>
			</tr>
		</table>
		<br>
		<font size="2">*) Required field</font>
	</form>
';
?>
