<?php
/*!
 *  @file
 *
 *  @brief	show overview of available physical devices
 *
 *  @date	2005
 */

require 'inc/func_dtd.php';

$gid  = validate_integer($_GET['gid']);
$tid  = validate_integer($_GET['tid']);
$msid = validate_integer($_GET['msid']);

$dtd = get_dtd_pathname($tid);
require $dtd;

$ret = $DB->GetModelFeatures($DTD['table'], $DTD['features'], $msid);
if ($ret) {
	$model_name = $ret['model'];
}
if (empty($model_name)) fatal(E_NOMODEL);

// determine sorting order from URL:
$order = trim($_GET['order']);
switch ($order) {
	case 'barcode':  $order = 'barcode';       break;
	case 'location': $order = 'location';      break;
	case 'status':   $order = 'status';        break;
	default:         $order = 'serial_number'; break;
}

$ret = $DB->ListDevices($gid, $tid, $msid, $order);

// get URL with "order" parameter stripped:
$parm_list = url_strip_parm($_SERVER['QUERY_STRING'], 'order');
$href_sub = $_SERVER['PHP_SELF'] . '?' . filter_string($parm_list);

echo '
	<h2>'.filter_string($model_name).'</h2>
	<table class="std_list">
		<tr>
			<th class="std_list_header"><a href="'.$href_sub.'&order=sn">S/N</a></th>
			<th class="std_list_header"><a href="'.$href_sub.'&order=barcode">Barcode</a></th>
			<th class="std_list_header"><a href="'.$href_sub.'&order=status">Status</a></th>
			<th class="std_list_header"><a href="'.$href_sub.'&order=location">Location</a></th>
';

if (has_permissions('w')) {
	echo '
			<th class="std_list_header"><!-- empty --></th>
';
}
if (has_permissions('d')) {
	echo '
			<th class="std_list_header"><!-- empty --></th>
';
}
echo '
		</tr>
';

$dids = array();	// array for physical device IDs
foreach ($ret as $row) {
	echo '
		<tr>
			<td class="std_list_entry">
				<a href="'.$_SERVER['PHP_SELF'].'?'.filter_string($_SERVER['QUERY_STRING']).'#'.$row['id'].'">'.filter_string($row['serial_number']).'</a>
			</td>
			<td class="std_list_entry">'.filter_string($row['barcode']).'</td>
			<td class="std_list_entry">'.filter_string($row['status']).'</td>
			<td class="std_list_entry">'.filter_string($row['location']).'</td>
';
	if (has_permissions('w')) {
		echo '
			<td class="std_list_entry">
				<a href="?component=physical&action=edit&did='.$row['id'].'">
					<img src="images/wrench.png" alt="Edit Device">
				</a>
			</td>
';
	}
	if (has_permissions('d')) {
		echo '
			<td class="std_list_entry">
				<a href="?component=physical&action=delete&did='.$row['id'].'" onclick="return ConfirmDelete()">
					<img src="images/trashcan.png" alt="Delete Device">
				</a>
			</td>
';
	}
	echo '
		</tr>
';
	$dids[] = $row['id'];	// add ID to array
}
echo '
	</table>
	<br>
	<hr>
';

/*
 * Show Links and Notes for all device IDs collected in $dids[] array.
 */
foreach ($dids as $k) {
	$row = $DB->FetchById('physical', array('id', 'serial_number'), $k);

	echo '
	<h3><a name="'.$row['id'].'">'.filter_string($row['serial_number']).'</a></h3>
';
	do_links($k);

	echo '
	<br>
';
	do_notes($k);

	echo '
	<br>
	<hr>
';
}
?>
