<?php
/*!
 *  @file
 *
 *  @brief	functions related to user-interface
 *
 *  @date	2005
 */

function do_links($device_id)
{
	global $DB;

	$did = validate_integer($device_id);

	echo '
		<table class="link">
			<tr>
				<th class="link" colspan="3">Links</th>
			</tr>
';

	$ret = $DB->FetchByValue('links', array('physical_id' => $did));
	foreach ($ret as $row) {
		echo '
				<td class="link">
					<a href="'.filter_string($row['url']).'">'.filter_string($row['comment']).'</a>
';
		if (has_permissions('w')) {
			echo '
				<td class="link">
					<a href="?component=link&action=edit&did='.$did.'&lid='.$row['id'].'">
						<img src="images/wrench.png" alt="Edit Link">
					</a>
				</td>
';
		}
		if (has_permissions('d')) {
			echo '
				<td class="link">
					<a href="?component=link&action=delete&lid='.$row['id'].'" onclick="return ConfirmDelete()">
						<img src="images/trashcan.png" alt="Delete Link">
					</a>
				</td>
';
		}
		echo '
			</tr>
';
	}
	echo '
		</table>
';

	if (has_permissions('w')) {
		echo '
			<a href="?component=link&action=edit&did='.$did.'">
				<img src="images/new.png" alt="New Link">
			</a>
';
	}
}

function do_notes($device_id)
{
	global $DB;

	$did = validate_integer($device_id);
	
	echo '
		<table class="note">
			<tr>
				<th class="note" colspan="4">Notes</th>
			</tr>
';
	$ret = $DB->FetchByValue('notes', array('physical_id' => $did));
	foreach ($ret as $row) {
		echo '
			<tr>
				<td class="note_date">
					<small>'.filter_string($row['last_date']).'<br>'.filter_string($row['last_time']).'</small>
				</td>
				<td class="note" style="vertical-align:top">
					'.filter_string($row['note']).'
				</td>
';
		if (has_permissions('w')) {
			echo '
				<td class="note">
					<a href="?component=note&action=edit&did='.$did.'&nid='.$row['id'].'">
						<img src="images/wrench.png" alt="Edit Note">
					</a>
				</td>
';
		}
		if (has_permissions('d')) {
			echo '
				<td class="note">
					<a href="?component=note&action=delete&nid='.$row['id'].'" onclick="return ConfirmDelete()">
						<img src="images/trashcan.png" alt="Delete Note">
					</a>
				</td>
';
		}
		echo '
			</tr>
';
	}
	echo '
		</table>
';
	if (has_permissions('w')) {
		echo '
			<a href="?component=note&action=edit&did='.$did.'">
				<img src="images/new.png" alt="New Note">
			</a>
';
	}
}

/*!
 *  Display page with fatal error message. After displaying the page the script
 *  is terminated.
 *
 *  @param[in] $message Error message to be displayed.
 *  @param[in] $private Indicates whether the message should be displayed only
 *                      to the administrator (kept private) while the message
 *                      displayed to a regular user is actually some standard
 *                      error message.
 *
 *  @returns
 *  Does not return; always terminates script with exit code 1.
 */
function fatal($message, $private = false)
{
	header('Location:', true);	// cancel any redirection

	$perm = get_credentials();
	if (has_permissions('m') && $private) {
		echo '<h4>'.E_INTERNAL.'</h4>';
	} else {
		echo $message;
	}
	exit(1);
}

/*!
 *  Format dropdown menu from database column data. The function selects all
 *  rows from a column of the given database table. The data of a row
 *  corresponds to a menu option which is formatted in a sequence of
 *  <code>\<option\></code> elements (one element for each menu option). This
 *  entire sequence is enclosed in a <code>\<select\></code> element. The
 *  name attribute of the <code>\<select\></code> element is set to the name
 *  of the column providing the menu options postfixed with the text
 *  <code>_menu</code>.
 *
 *  @param[in] $table    Name of database table.
 *  @param[in] $column   Name of column in $table holding the data for the
 *                       menu options. This parameter is used as the value
 *                       for the name attribute of the <code>\<select\></code>
 *                       element.
 *  @param[in] $selected Sets the default selection for the menu (optional).
 *  @param[in] $fl_other Controls whether to add an extra menu option
 *                       <code>\<other\></code> which indicates the
 *                       appropriate menu option is not present in the menu.
 *                       The <code>\<other\></code> option will be the default
 *                       if $selected is empty.
 *
 *  @returns
 *  Single line describing the dropdown menu element.
 */
function fmt_dropdown_menu($table, $column, $selected, $fl_other)
{
	global $DB;

	$line = '<select name="' . $column . '_menu">';
	$ret = $DB->Fetch($table, array($column), $column);
	foreach ($ret as $row) {
		$line .= '<option value="' . filter_string($row[$column]) . '"';
		if (!strcasecmp($row[$column], $selected))
			$line .= ' selected';
		$line .= '>' . filter_string($row[$column]) . '</option>';
	}
	if ($fl_other) {
		$line .= '<option value="other"';
		if (empty($selected)) $line .= ' selected';
		$line .= '>' . filter_string("<other>") . '</option>';
	}
	$line .= '</select>';

	return $line;
}

/*!
 *  Format element for text input. This function creates an
 *  <code>\<input\></code> element for use in a FORM.
 *
 *  @param[in] $name     Name attribute for the element. The function
 *                       automatically adds the text <code>_text</code> to
 *                       the end of $name.
 *  @param[in] $value    Initial content of text field.
 *  @param[in] $size     Size of text field on UI (in characters).
 *  @param[in] $max_size Maximum input length for text field (in characters).
 *
 *  @returns
 *  Single line describing the text input field.
 */
function fmt_text_input($name, $value, $size, $max_size)
{
	validate_integer($size);
	validate_integer($max_size);

	$line  = '<input name="'.$name.'_text" type="text" size="'.$size.'"';
	$line .= ' maxlength="'.$max_size.'" value="'.filter_string($value).'">';

	return $line;
}

/*!
 *  Format element for radio button input. This function creates an
 *  <code>\<input\></code> element for use in a FORM.
 *
 *  @param[in] $name     Name attribute for the element. The function
 *                       automatically adds the text <code>_rbtn</code> to
 *                       the end of $name.
 *  @param[in] $choices  Array holding the labels for the radio buttons.
 *  @param[in] $default  Choice (in $choices) that should be selected by
 *                       default. If omitted, the first entry in $choices
 *                       is used.
 *
 *  @returns
 *  Array where each entry describes one radio button input field.
 */
function fmt_rbtn_input($name, $choices, $default = '')
{
	$lines = array();
	$name_attr = $name . '_rbtn';

	// determine which default to use:
	if (empty($default)) {
		$idx_default = 0;
	} else {
		$idx_default = array_search($default, $choices);
		if ($idx_default === false) {
			$idx_default = 0;
		}
	}

	$idx = 0; // array iterator
	foreach ($choices as $c) {
		$id  = $name . '_id' . $idx;
		$val = filter_string($c);

		$l  = '<input id="'.$id.'" name="'.$name_attr.'" type="radio"';
		$l .= ' value="'.$val.'" '.($idx==$idx_default?'checked':'').'>';
		$l .= '<label for="'.$id.'">'.$val.'</label>';
		array_push($lines, $l);

		$idx++;
	}

	return $lines;
}

/*!
 *  Format list of checkboxes from database column data. This function creates
 *  an <code>\<input\></code> element for use in a FORM. Each checkbox element
 *  is identified by a unique "name" attribute. This attribute consists of the
 *  column name followed by the literal "_cbox_" and a row ID number.
 *
 *  @param[in] $table    Name of database table.
 *  @param[in] $column   Name of column in $table holding the data for the
 *                       checkboxes. This parameter is used as a prefix for
 *                       the name attribute of the <code>\<input\></code>
 *                       element.
 *  @param[in] $selected Array which contains the labels that should be checked
 *                       or selected.
 *
 *  @returns
 *  Array where each entry describes one checkbox input field.
 */
function fmt_cbox_input($table, $column, $selected)
{
	global $DB;

	$lines = array();

	$ret = $DB->Fetch($table, array('id', $column), $column);

	foreach ($ret as $row) {
		$name = $column . '_cbox_' . $row['id'];
		$val = filter_string($row[$column]);

		$checked = in_array($row[$column], $selected); // select item or not

		/*
		 * Put checkbox element inside <label> instead of the other way
		 * around. By doing so, the whitespace between the checkbox and
		 * the text becomes clickable too.
		 */
		$l  = '<label>';
		$l .= '<input name="'.$name.'"';
		$l .= ' type="checkbox" value="'.$val.'" ';
		$l .= ($checked===true?'checked':'').'>';
		$l .= $val.'</label>';
		array_push($lines, $l);
	}

	return $lines;
}
?>
